@@ -1,6 +1,6 @@
 
 from __future__ import print_function
-from statsmodels.tsa.tests.test_stattools import CheckCoint, TestCoint_t
+from statsmodels.tsa.tests.test_stattools import TestCoint_t
 
 
 #test whether t-test for cointegration equals that produced by Stata
