@@ -7,12 +7,15 @@ Author: josef-pktd
 
 
 import numpy as np
-from scipy import stats
 from numpy.testing import assert_almost_equal
+import matplotlib.pyplot as plt
+
 import statsmodels.api as sm
-from statsmodels.sandbox.regression.onewaygls import OneWayLS
 from statsmodels.stats.diagnostic import recursive_olsresiduals
 from statsmodels.sandbox.stats.diagnostic import _recursive_olsresiduals2 as recursive_olsresiduals2
+from statsmodels.sandbox.stats.diagnostic import (
+    breaks_hansen, breaks_cusumolsresid)
+
 
 #examples from ex_onewaygls.py
 #choose example
@@ -71,7 +74,6 @@ print(rresid_scaled[skip-1:])
 
 assert_almost_equal(rparams[-1], res1.params)
 
-import matplotlib.pyplot as plt
 plt.plot(rcusum)
 plt.plot(rcusumci[0])
 plt.plot(rcusumci[1])
@@ -80,7 +82,7 @@ plt.plot(rresid)
 plt.plot(np.abs(rresid))
 
 print('cusum test reject:')
-print(((rcusum[1:]>rcusumci[1])|(rcusum[1:]<rcusumci[0])).any())
+print(((rcusum[1:]>rcusumci[1]) | (rcusum[1:]<rcusumci[0])).any())
 
 rresid2, rparams2, rypred2, rresid_standardized2, rresid_scaled2, rcusum2, rcusumci2 = \
             recursive_olsresiduals2(res1, skip)
@@ -90,9 +92,6 @@ assert_almost_equal(rparams[skip:], rparams2[skip:],13)
 #plt.show()
 
 ####################  Example break test
-#import statsmodels.sandbox.tools.stattools
-from statsmodels.sandbox.stats.diagnostic import breaks_hansen, \
-        breaks_cusumolsresid#, breaks_cusum
 H, crit95, ft, s = breaks_hansen(res1)
 print(H)
 print(crit95)
@@ -105,6 +104,3 @@ print(supb, pval, crit)
 #print breaks_cusumolsresid(rresid[skip:])
 #this function is still completely wrong, cut and paste doesn't apply
 #print breaks_cusum(rresid[skip:])
-
-
-
