@@ -9,13 +9,9 @@ copyright: Simplified BSD see license.txt
 """
 from __future__ import print_function
 import numpy as np
-from numpy.testing import assert_almost_equal
-
-import matplotlib.pyplot as plt
 
 import numdifftools as ndt
 
-import statsmodels.api as sm
 from statsmodels.sandbox import tsa
 from statsmodels.tsa.arma_mle import Arma  # local import
 from statsmodels.tsa.arima_process import arma_generate_sample
@@ -143,4 +139,3 @@ if 'arma' in examples:
 
     #fmin estimates for coefficients in ARMA(3,3) look good
     #but not inverse Hessian, sometimes negative values for variance
-
